@@ -1,19 +1,19 @@
 import re
 
-from pymafia import ash
-from pymafia.utils import get_property
+from pymafia import ash, utils
 
 
-def have():
+def have() -> bool:
     """Return True if the player has the shrine to the Barrel god unlocked, False otherwise."""
-    return get_property("barrelShrineUnlocked", bool)
+    return utils.get_property("barrelShrineUnlocked", bool)
 
 
-def smash_free():
+def smash_free() -> bool:
     """Smash the free barrels in The Barrel full of Barrels."""
     if not have():
-        raise RuntimeError("need a shrine to the Barrel god installed")
+        return False
 
     pattern = '<div class="ex"><a class="spot" href="([^"]+)"><img title="A barrel"'
     for barrel in re.findall(pattern, ash.visit_url("barrel.php")):
         ash.visit_url(barrel)
+    return True
